yakumo.nova.v2.cloudpipe

Package yakumo :: Package nova :: Package v2 :: Module cloudpipe |
[hide private]
[frames] | no frames]

# Module cloudpipe

source code

Resource class and its manager for cloudpipes in Compute API v2

Classes | [hide private]
| Resource Resource class for cloudpipes in Compute API v2
| Manager Manager class for cloudpipes in Compute API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``server``'``,` `'``instance_id``'``,` <yakumo.mapper.`...``
| __package__ = ``'``yakumo.nova.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('server',
        'instance_id',
        <yakumo.mapper.Resource object at 0x7f132fed5110>),
       ('project',
        'project_id',
        <yakumo.mapper.Resource object at 0x7f132fed5150>),
       ('internal_ip',
        'internal_ip',
      ...